@@ -4,10 +4,10 @@ from PyQt5 import QtCore
 from PyQt5.QtCore import pyqtSignal, QItemSelection, QModelIndex, QItemSelectionModel
 from PyQt5.QtWidgets import QTreeView, QWidget, QTreeWidget, QTreeWidgetItem, QAbstractItemView, QAbstractItemDelegate
 
-from pwspy_gui.PWSAnalysisApp.plugins.acquisitionSequencer._treeModel.model import TreeModel
+from pwspy_gui.PWSAnalysisApp.plugins.acquisitionSequencer._treeModel import TreeModel
 from pwspy.utility.acquisition import SequencerStep
 from pwspy_gui.PWSAnalysisApp.plugins.acquisitionSequencer._ui.Delegate import IterationRangeDelegate
-from pwspy.utility.acquisition.sequencerCoordinate import IterationRangeCoordStep, SequencerCoordinateRange
+from pwspy.utility.acquisition.sequencerCoordinate import SequencerCoordinateRange
 
 
 class MyTreeView(QTreeView):
@@ -32,7 +32,10 @@ class MyTreeView(QTreeView):
         self.setCurrentIndex(idx)
 
         delegate: IterationRangeDelegate = self.itemDelegate()
-        self.closeEditor(delegate.editor, QAbstractItemDelegate.NoHint)  # Close the editor to indicate to the user that the change has been accepted.
+        try:
+            self.closeEditor(delegate.editor, QAbstractItemDelegate.NoHint)  # Close the editor to indicate to the user that the change has been accepted.
+        except RuntimeError:  # Sometimes the editor has been deleted in the c++ layer causing an issue
+            pass
 
     def setRoot(self, root: SequencerStep) -> None:
         """
@@ -54,9 +57,9 @@ class MyTreeView(QTreeView):
         step: SequencerStep = idx.internalPointer()
         coordSteps = []
         while step is not self.model().invisibleRootItem(): # This will break out once we reach the root item.
-            coordStep = step.data(QtCore.Qt.EditRole)  # The item delegate saves an iterationRangeCoordStep in the `editRole` data slot of steps.
+            coordStep = step.data(QtCore.Qt.EditRole)  # The item delegate saves an tuple indicated the range of iterations selected in the `editRole` data slot of steps.
             if coordStep is None:
-                coordSteps.append(IterationRangeCoordStep(step.id, None))
+                coordSteps.append((step.id, None))
             else:
                 coordSteps.append(coordStep)
             step = step.parent()  # On the next iteration look at the parent of the selected step.
@@ -67,7 +70,7 @@ class MyTreeView(QTreeView):
         return self._currentCoordRange
 
     def _currentChanged(self, current: QModelIndex, previous: QModelIndex):
-        if current.internalPointer() is not None: # In some cases we may change to index to something blank that has not pointer
+        if current.internalPointer() is not None:  # In some cases we may change to index to something blank that has not pointer
             self.currentItemChanged.emit(current.internalPointer())
 
 
